@@ -38,3 +38,13 @@ double C_test_max_lt(std::vector<double> v, double value){
   auto it = hesim::max_lt(v.begin(), v.end(), value);
   return *it;
 }
+
+// [[Rcpp::export]]
+double C_test_find_interval(double x, std::vector<double> vec){
+  return hesim::find_interval(x, vec);
+}
+
+// [[Rcpp::export]]
+bool C_test_is_member_of(double x, std::vector<double> lookup){
+  return hesim::is_member_of(x, lookup);
+}
